
const {resolve} = require('path')
const HtmlWebpackPlugin = require('html-webpack-plugin')

/**
 * entry:
 * 1 string  --> './src/index.js' -- 单入口
 *      打包形成一个chunk，输出一个bundle文件
 *      chunk名称默认是main
 * 2 array --> ['./src/index.js,'./src/add.js']  -- 多入口
 *      所有入口文件最终形成一个chunk，输出一个bundle文件
 *      用途：HMR热更新中，让html热更新生效
 * 3 object --> {index:'./src/index.js',add:./src/add.js'}
 *      多入口，形成多个chunk，输出多个bundle文件
 * 
 * 4 特殊用法
 *      object --> {index:['./src/index.js','./src/count.js'],add:'./src/add.js'}
 *      index 多文件形成一个chunk，输出一个文件
 *      add 一个文件形成一个chunk，输出一个文件
 */
module.exports = {
    entry: './src/index.js',
    output: {
        filename:'[name].js',
        path:resolve(__dirname,'build')
    },
    plugins: [
        new HtmlWebpackPlugin()
    ],
    mode: 'development'
}